@@ -149,7 +149,7 @@ class xmlDocPlasma(xmlDoc):
                                                     xmlNewArea)[0]
                     oldAreaCaption = xpath.Evaluate('child::caption',
                                                     oldAreaNode)[0]
-                    if newAreaCaption and oldAreaCaption:
+                    if newAreaCaption is not None and oldAreaCaption is not None:
                         xmlNewArea.replace(newAreaCaption, oldAreaCaption)
                         self.setActionArea(xmlNewArea, "replace")
                     baseNode.replace(oldAreaNode, xmlNewArea)
