@@ -172,6 +172,24 @@ class BinhostsBase(Cachable):
                 self.duration = int((time.time() - start_ts) * 1000)
                 self.outdated = int(start_ts) - self.timestamp > parent.actual_period
                 self.downgraded = self.timestamp < parent.last_ts
+                
+                fn, data = self.parent.fetch_envdata(self.host)
+                if fn:
+                    cp = ConfigParserCaseSens()
+                    try:
+                        cp.read_string(data)
+                        if "update" in cp.sections():
+                            self.level = int(cp["update"]["level"])
+
+                            #TODO this is for debugging
+                            # self.level = 2
+
+                        else:
+                            self.level = None
+                    except (CPError, KeyError) as e:
+                        self.level = None
+                else:
+                    self.level = None
             except BaseException as e:
                 if isinstance(e, KeyboardInterrupt):
                     raise
